@@ -4,7 +4,7 @@ import readline
 import argcomplete
 import neotermcolor
 
-from elbus.rpc import RpcException
+from busrt.rpc import RpcException
 
 from neotermcolor import colored
 
@@ -210,6 +210,12 @@ def append_svc_cli(root_sp):
     p = sp.add_parser('edit', help='edit service config')
     p.add_argument('i', metavar='SVC').completer = ComplSvc()
 
+    p = sp.add_parser('enable', help='enable service')
+    p.add_argument('i', metavar='SVC').completer = ComplSvc()
+
+    p = sp.add_parser('disable', help='disable service')
+    p.add_argument('i', metavar='SVC').completer = ComplSvc()
+
     p = sp.add_parser('test', help='test service')
     p.add_argument('i', metavar='SVC').completer = ComplSvc()
 
